import tkinter as tk
from tkinter import filedialog
from tkinter import messagebox
import pandas as pd
import math

class GaussCalculator:
    def __init__(self, root):
        self.root = root
        self.root.title("Gauss Alanı Hesaplayıcı")

        self.coordinates = None

        self.file_label = tk.Label(root, text="Excel dosyası seçilmedi.")
        self.file_label.pack(pady=10)

        self.load_button = tk.Button(root, text="Excel Dosyasını Yükle", command=self.load_excel_file)
        self.load_button.pack(pady=5)

        self.data_frame = tk.Frame(root)
        self.data_frame.pack(pady=10)

        self.x_entries = []
        self.y_entries = []

        self.calculate_button = tk.Button(root, text="Hesapla", command=self.calculate_gauss_area, state=tk.DISABLED)
        self.calculate_button.pack(pady=5)

        self.result_label = tk.Label(root, text="")
        self.result_label.pack(pady=10)

        self.about_button = tk.Button(root, text="Hakkında", command=self.show_about_info)
        self.about_button.pack(pady=5)

    def load_excel_file(self):
        file_path = filedialog.askopenfilename(filetypes=[("Excel files", "*.xlsx;*.xls")])
        if file_path:
            try:
                self.df = pd.read_excel(file_path)
                self.coordinates = [(row['X'], row['Y']) for index, row in self.df.iterrows()]
                num_points = len(self.coordinates)
                self.file_label.config(text=f"Excel dosyası: {file_path}")
                self.calculate_button.config(state=tk.NORMAL)
            except Exception as e:
                self.file_label.config(text="Bir hata oluştu. Excel dosyasını kontrol edin.")
                print(e)

    def calculate_gauss_area(self):
        if self.coordinates:
            try:
                self.update_data_from_entries()
                num_points = len(self.coordinates)
                gauss_area = self._calculate_area(self.coordinates)
                self.result_label.config(text=f"Nokta Sayısı: {num_points} - Gauss Alanı: {gauss_area:.2f}")
            except Exception as e:
                self.result_label.config(text="Bir hata oluştu.")
                print(e)

    def update_data_from_entries(self):
        for index, entry_index in enumerate(range(len(self.x_entries))):
            self.df.at[index, 'X'] = self.x_entries[entry_index].get()
            self.df.at[index, 'Y'] = self.y_entries[entry_index].get()

    def _calculate_area(self, coordinates):
        total_area = 0
        for i in range(len(coordinates)):
            x1, y1 = coordinates[i]
            x2, y2 = coordinates[(i + 1) % len(coordinates)]
            total_area += (x1 * y2 - x2 * y1)
        return abs(total_area) / 2

    def show_about_info(self):
        messagebox.showinfo("Hakkında", "Ertan Taner Tunç - ettunc.com")

root = tk.Tk()
app = GaussCalculator(root)
root.mainloop()
